from bottle import Bottle, run, template, static_file, request, redirect
from markdown import markdown

import os
import re

app = Bottle()

def hello():
    return "Coucou !"
app.route('/')(hello)

@app.route('/b/<nom>')
def bonjour(nom):
  return 'Bonjour '+nom

def habillage(titre,contenu):
  template_page = '<html><head><title>{{titre}}</title></head><body><h1>{{titre}}</h1>{{!contenu}}</body></html>'
  return template(template_page,titre=titre,contenu=contenu)

# Wiki
def contenu_page_wiki(nom_page):
  with open(os.path.join('wiki',nom_page+'.txt'),encoding='utf8') as f:
    return f.read()

def cree_page_wiki(nom_page,contenu):
  with open(os.path.join('wiki',nom_page+'.txt'),'w',encoding='utf8') as f:
    f.write(contenu)

def contenu_edite_page_wiki(nom,contenu=''):
	formulaire = '''<p>Éditez le contenu de la page <kbd>{{nom}}</kbd>
	(au format <a href="https://michelf.ca/projets/php-markdown/syntaxe/">markdown</a>):</p>
	<form method="post" action="/wiki/e/{{nom}}" id="form_edite_page">
	<textarea name="contenu" cols=50 rows=20>{{contenu}}</textarea>
	<input type="submit" value="Enregister" name="enregistrer">
	</form>'''
	return template(formulaire,nom=nom,contenu=contenu)
	
@app.route('/wiki')
def wiki_liste_pages():
	contenu = '<p>choisir une page existante:</p>'
	contenu +='<ul>'
	for page in os.listdir(os.path.join('wiki')):
		nom_page = re.search(r'^(.*)\.txt$',page)
		if nom_page:
			contenu += template('<li><a href="wiki/{{page}}">{{page}}</a></li>',page=nom_page.group(1))
	contenu += '</ul>'
	contenu += '<p>ou créer une nouvelle page:</p>'
	contenu += '''<form method="post" action="/wiki/e" id="form_cree_page">
	<input type="text" value="nom_de_la_page" name="nom" >
	<input type="submit" value="Créer" name="creer">
	</form>'''
	return habillage(titre='liste des pages',contenu=contenu)
		
@app.route('/wiki/<nom>')
def wiki_page(nom):
	try:
		template_wiki_page='''{{!page}}
		<p><a href="/wiki/e/{{nom}}">éditer cette page</a></p>
		<p><a href="/wiki">liste des pages</a></p>'''
		page=markdown(contenu_page_wiki(nom))
		contenu=template(template_wiki_page,nom=nom,page=page)
		return habillage(titre=nom,contenu=contenu)
	except IOError:
		return habillage(titre=nom+' (page non trouvée)',contenu=contenu_edite_page_wiki(nom))

@app.route('/wiki/e',method='POST')
def wiki_cree_post():
	nom = request.forms.nom
	redirect('/wiki/e/'+nom)

@app.route('/wiki/e/<nom>')
def wiki_edite_page_get(nom):
	try:
		contenu_page=contenu_page_wiki(nom)
		return habillage(titre=nom+' (édition)',contenu=contenu_edite_page_wiki(nom,contenu_page))
	except IOError:
		return habillage(titre=nom+' (page non trouvée)',contenu=contenu_edite_page_wiki(nom))

@app.route('/wiki/e/<nom>',method='POST')
def wiki_edite_page_post(nom):
	contenu = request.forms.contenu
	cree_page_wiki(nom,contenu)
	redirect('/wiki/'+nom)

# Galerie
def lien_image(nom):
	uri = 'galerie/i/'+nom
	template_lien_image='''<table style='display: inline;'>
	<tr><td><a href="{{uri}}"><img
		style="max-width:100px; max-height:100px; padding:5px; margin:5px; border:solid 1px black;"
		src="{{uri}}" alt="{{nom}}" /></a></td></tr>
	<tr><td>{{nom}}</td></tr>
	</table>'''
	return template(template_lien_image,nom=nom,uri=uri)

@app.route('/galerie/i/<fichier>')
def fichier_image(fichier):
	return static_file(fichier, root='images')

@app.route('/galerie')
def galerie():
	contenu=''
	for fichier in os.listdir('images'):
		contenu += lien_image(os.path.join(fichier))
	return habillage(titre='Galerie',contenu=contenu)

run(app, host='localhost', port=8080)
